@@ -5,7 +5,7 @@ if (winch::winch_available() && require(vctrs)) {
     rlang_trace_use_winch = TRUE
   )
 
-  winch::winch_init_library(vctrs:::vctrs_init$dll[["path"]])
+  winch::winch_init_library(vctrs:::vctrs_init_library$dll[["path"]])
 
   tryCatch(vctrs::vec_as_location(quote, 2), error = identity)
 }
